@@ -1,7 +1,10 @@
 use std::mem::take;
 
 use self::input::{Buffer, ParserInput};
-use crate::error::{Error, ErrorKind};
+use crate::{
+    error::{Error, ErrorKind},
+    Parse,
+};
 use swc_atoms::js_word;
 use swc_common::Span;
 use swc_css_ast::*;
@@ -29,6 +32,7 @@ pub struct ParserConfig {
 struct Ctx {
     allow_operation_in_value: bool,
     allow_separating_value_with_space: bool,
+    allow_separating_value_with_comma: bool,
 
     disallow_comma_in_media_query: bool,
 
@@ -71,18 +75,7 @@ where
     }
 
     pub fn parse_all(&mut self) -> PResult<Stylesheet> {
-        let start = self.input.cur_span()?;
-        let rules = self.parse_rules(RuleContext {
-            is_top_level: true,
-            parse_selectors: true,
-        })?;
-
-        let last = self.input.last_pos()?;
-
-        Ok(Stylesheet {
-            span: Span::new(start.lo, last, Default::default()),
-            rules,
-        })
+        self.parse()
     }
 
     fn parse_rules(&mut self, ctx: RuleContext) -> PResult<Vec<Rule>> {
@@ -202,3 +195,23 @@ struct RuleContext {
     is_top_level: bool,
     parse_selectors: bool,
 }
+
+impl<I> Parse<Stylesheet> for Parser<I>
+where
+    I: ParserInput,
+{
+    fn parse(&mut self) -> Result<Stylesheet, Error> {
+        let start = self.input.cur_span()?;
+        let rules = self.parse_rules(RuleContext {
+            is_top_level: true,
+            parse_selectors: true,
+        })?;
+
+        let last = self.input.last_pos()?;
+
+        Ok(Stylesheet {
+            span: Span::new(start.lo, last, Default::default()),
+            rules,
+        })
+    }
+}
